Crate solverforge_cvrp

Crate solverforge_cvrp 

Modules

route_hooks
Route-local hook bundle used by #[planning_list_variable(domain = "cvrp")].
savings_hooks
Clarke-Wright savings hook bundle used by #[planning_list_variable(domain = "cvrp")].

Structs

MatrixDistanceMeter
MatrixIntraDistanceMeter
ProblemData
Immutable problem data shared by all vehicles.

Constants

UNREACHABLE
Matrix sentinel for a leg that cannot be traversed.

Traits

VrpSolution
Trait implemented by a planning solution that holds a fleet of vehicles, each carrying a *const ProblemData pointer and a list of visited stops.

Functions

depot_for_entity
get_route
Returns a cloned snapshot of the route for entity entity_idx.
replace_route
Replaces the current route for entity entity_idx.
route_distance
Distance between two element indices for the route owner.
route_feasible
Returns true if the route satisfies stock CVRP route-local feasibility.
savings_depot_for_entity
Depot token used by Clarke-Wright construction.
savings_distance
Construction distance used by Clarke-Wright for models that share CVRP route data.
savings_feasible
Construction admissibility used by Clarke-Wright for stock CVRP route data.
savings_metric_class
Construction metric class for the route owner.