pub struct ProblemData {
pub capacity: i64,
pub depot: usize,
pub demands: Vec<i32>,
pub distance_matrix: Vec<Vec<i64>>,
pub time_windows: Vec<(i64, i64)>,
pub service_durations: Vec<i64>,
pub travel_times: Vec<Vec<i64>>,
pub vehicle_departure_time: i64,
}Expand description
Immutable problem data shared by all vehicles.
Stored via raw pointer in each vehicle so the framework can clone vehicles freely during local search without copying matrices.
Fields
capacity: i64depot: usizedemands: Vec<i32>distance_matrix: Vec<Vec<i64>>time_windows: Vec<(i64, i64)>service_durations: Vec<i64>travel_times: Vec<Vec<i64>>vehicle_departure_time: i64Auto Trait Implementations
impl Freeze for ProblemData
impl RefUnwindSafe for ProblemData
impl Send for ProblemData
impl Sync for ProblemData
impl Unpin for ProblemData
impl UnsafeUnpin for ProblemData
impl UnwindSafe for ProblemData