Modules
- route_
hooks - Route-local hook bundle used by
#[planning_list_variable(domain = "cvrp")]. - savings_
hooks - Clarke-Wright savings hook bundle used by
#[planning_list_variable(domain = "cvrp")].
Structs
- Matrix
Distance Meter - Matrix
Intra Distance Meter - Problem
Data - Immutable problem data shared by all vehicles.
Constants
- UNREACHABLE
- Matrix sentinel for a leg that cannot be traversed.
Traits
- VrpSolution
- Trait implemented by a planning solution that holds a fleet of vehicles,
each carrying a
*const ProblemDatapointer and a list of visited stops.
Functions
- depot_
for_ entity - get_
route - Returns a cloned snapshot of the route for entity
entity_idx. - replace_
route - Replaces the current route for entity
entity_idx. - route_
distance - Distance between two element indices for the route owner.
- route_
feasible - Returns
trueif the route satisfies stock CVRP route-local feasibility. - savings_
depot_ for_ entity - Depot token used by Clarke-Wright construction.
- savings_
distance - Construction distance used by Clarke-Wright for models that share CVRP route data.
- savings_
feasible - Construction admissibility used by Clarke-Wright for stock CVRP route data.
- savings_
metric_ class - Construction metric class for the route owner.