Crate solverforge_cvrp

Crate solverforge_cvrp 

Structs

MatrixDistanceMeter
MatrixIntraDistanceMeter
ProblemData
Immutable problem data shared by all vehicles.

Traits

VrpSolution
Trait implemented by a planning solution that holds a fleet of vehicles, each carrying a *const ProblemData pointer and a list of visited stops.

Functions

depot_for_entity
get_route
Returns a cloned snapshot of the route for entity entity_idx.
replace_route
Replaces the current route for entity entity_idx.
route_distance
Distance between two element indices for the route owner.
route_feasible
Returns true if the route satisfies capacity and time-window constraints.
route_metric_class
Construction metric class for the route owner.