Structs
- Matrix
Distance Meter - Matrix
Intra Distance Meter - Problem
Data - Immutable problem data shared by all vehicles.
Traits
- VrpSolution
- Trait implemented by a planning solution that holds a fleet of vehicles,
each carrying a
*const ProblemDatapointer and a list of visited stops.
Functions
- depot_
for_ entity - get_
route - Returns a cloned snapshot of the route for entity
entity_idx. - replace_
route - Replaces the current route for entity
entity_idx. - route_
distance - Distance between two element indices for the route owner.
- route_
feasible - Returns
trueif the route satisfies capacity and time-window constraints. - route_
metric_ class - Construction metric class for the route owner.